# Quickstart

The quickstart will walk you through creating and running a graph with existing nodes step by step and is aimed at getting you off the ground. If you prefer to investigate on your own, please have a look at the [example project git](https://gitlab.csl.uni-bremen.de/livenodes/example-project) which provides multiple awesome working examples.

What you'll need: 
- a working conda installation (required by LN-Studio). 
- x mins.

What we'll build:  
A simple graph that creates a sinus and cosinus wave, subtracts them and plots all three values as graphs over time.

TODO: add an interaction element


## Setup

Create a conda environment and install livenodes and LN-Studio.

TODO: finish this up -> for now i recommend copying the example project :D
TODO: LN-Studio when opened in an empty project should ask if it should scafold a project


## Start 

To open the gui application, run:

```
conda activate example_project
lns
```

## Create 

## Run